@@ -6,7 +6,14 @@ def test_get_rules():
     md = MarkdownIt("zero")
     # print(md.get_all_rules())
     assert md.get_all_rules() == {
-        "core": ["normalize", "block", "inline"],
+        "core": [
+            "normalize",
+            "block",
+            "inline",
+            "linkify",
+            "replacements",
+            "smartquotes",
+        ],
         "block": [
             "table",
             "code",
@@ -15,9 +22,9 @@ def test_get_rules():
             "hr",
             "list",
             "reference",
+            "html_block",
             "heading",
             "lheading",
-            "html_block",
             "paragraph",
         ],
         "inline": [
@@ -55,9 +62,9 @@ def test_load_presets():
             "hr",
             "list",
             "reference",
+            "html_block",
             "heading",
             "lheading",
-            "html_block",
             "paragraph",
         ],
         "inline": [
@@ -76,6 +83,13 @@ def test_load_presets():
     }
 
 
+def test_override_options():
+    md = MarkdownIt("zero")
+    assert md.options["maxNesting"] == 20
+    md = MarkdownIt("zero", {"maxNesting": 99})
+    assert md.options["maxNesting"] == 99
+
+
 def test_enable():
     md = MarkdownIt("zero").enable("heading")
     assert md.get_active_rules() == {
@@ -215,3 +229,51 @@ def test_renderInline():
     md = MarkdownIt("zero")
     tokens = md.renderInline("abc\n\n*xyz*")
     assert tokens == "abc\n\n*xyz*"
+
+
+def test_emptyStr():
+    md = MarkdownIt()
+    tokens = md.parseInline("")
+    assert tokens == [
+        Token(
+            type="inline",
+            tag="",
+            nesting=0,
+            attrs=None,
+            map=[0, 1],
+            level=0,
+            children=[],
+            content="",
+            markup="",
+            info="",
+            meta={},
+            block=False,
+            hidden=False,
+        )
+    ]
+
+
+def test_empty_env():
+    """Test that an empty `env` is mutated, not copied and mutated."""
+    md = MarkdownIt()
+
+    env = {}
+    md.render("[foo]: /url\n[foo]", env)
+    assert "references" in env
+
+    env = {}
+    md.parse("[foo]: /url\n[foo]", env)
+    assert "references" in env
+
+
+def test_table_tokens(data_regression):
+    md = MarkdownIt("js-default")
+    tokens = md.parse(
+        """
+| Heading 1 | Heading 2
+| --------- | ---------
+| Cell 1    | Cell 2
+| Cell 3    | Cell 4
+    """
+    )
+    data_regression.check([t.as_dict() for t in tokens])
